@@ -6,7 +6,7 @@ use strict;
 use 5.008;
 
 
-our $VERSION = '0.1400';
+our $VERSION = '0.1500';
 
 
 1; # End of Games::Solitaire::Verify
@@ -23,7 +23,7 @@ Games::Solitaire::Verify - verify solutions for solitaire games.
 
 =head1 VERSION
 
-version 0.1400
+version 0.1500
 
 =head1 SYNOPSIS
 
@@ -122,7 +122,7 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Games-Solitaire-Verify>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Games-Solitaire-Verify>
 
 =item *
 
@@ -154,7 +154,7 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/Games-Solitaire-Verify>
+L<http://cpants.cpanauthors.org/dist/Games-Solitaire-Verify>
 
 =item *
 
@@ -185,7 +185,7 @@ L<http://deps.cpantesters.org/?module=Games::Solitaire::Verify>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-games-solitaire-verify at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Games-Solitaire-Verify>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Games-Solitaire-Verify>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
