@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 
-our $VERSION = '0.1400';
+our $VERSION = '0.1500';
 
 use parent 'Games::Solitaire::Verify::Base';
 
@@ -264,7 +264,7 @@ Solitaire card.
 
 =head1 VERSION
 
-version 0.1400
+version 0.1500
 
 =head1 SYNOPSIS
 
@@ -409,7 +409,7 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Games-Solitaire-Verify>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Games-Solitaire-Verify>
 
 =item *
 
@@ -441,7 +441,7 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/Games-Solitaire-Verify>
+L<http://cpants.cpanauthors.org/dist/Games-Solitaire-Verify>
 
 =item *
 
@@ -472,7 +472,7 @@ L<http://deps.cpantesters.org/?module=Games::Solitaire::Verify>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-games-solitaire-verify at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Games-Solitaire-Verify>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Games-Solitaire-Verify>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
