@@ -4,9 +4,9 @@ use warnings;
 use strict;
 
 
-our $VERSION = '0.1400';
+our $VERSION = '0.1500';
 
-use parent 'Games::Solitaire::Verify::Base';
+use parent 'Games::Solitaire::Verify::Solution::Base';
 
 # TODO : Merge with lib/Games/Solitaire/Verify/Solution.pm
 
@@ -20,14 +20,7 @@ use Games::Solitaire::Verify::State;
 use List::Util qw( min );
 
 __PACKAGE__->mk_acc_ref([qw(
-    _input_fh
-    _line_num
     _move_line
-    _variant
-    _variant_params
-    _state
-    _move
-    _reached_end
     _output_fh
     )]);
 
@@ -50,9 +43,9 @@ sub _init
             )
         );
     }
-    $self->_input_fh($args->{input_fh});
+    $self->_i($args->{input_fh});
     $self->_state(undef);
-    $self->_line_num(0);
+    $self->_ln(0);
     $self->_reached_end(0);
     $self->_output_fh($args->{output_fh});
 
@@ -72,7 +65,7 @@ sub _out_line
 {
     my ($self, $line) = @_;
 
-    return $self->_out("$line\n");
+    return $self->_out($line);
 }
 
 sub _calc_variant_args
@@ -120,9 +113,9 @@ sub _read_state
 {
     my $self = shift;
 
-    my $line = $self->_get_line();
+    my $line = $self->_l();
 
-    if ($line ne "")
+    if ($line ne "\n")
     {
         die "Non empty line before state";
     }
@@ -131,22 +124,22 @@ sub _read_state
 
     my $str = "";
 
-    while (($line = $self->_get_line()) && ($line ne ""))
+    while (($line = $self->_l()) && ($line ne "\n"))
     {
-        $str .= $line . "\n";
+        $str .= $line;
     }
 
     $self->_assign_read_new_state($str);
 
     $self->_out($str);
 
-    $self->_out_line("");
-    while (defined($line = $self->_get_line()) && ($line eq ""))
+    $self->_out_line("\n");
+    while (defined($line = $self->_l()) && ($line eq "\n"))
     {
         $self->_out_line($line);
     }
 
-    if ($line !~ m{\A={3,}\z})
+    if ($line !~ m{\A={3,}\n\z})
     {
         die "No ======== separator";
     }
@@ -159,23 +152,23 @@ sub _read_move
 {
     my $self = shift;
 
-    my $line = $self->_get_line();
+    my $line = $self->_l();
 
-    if ($line ne "")
+    if ($line ne "\n")
     {
         die "No empty line before move";
     }
 
     $self->_out_line($line);
 
-    $line = $self->_get_line();
+    $line = $self->_l();
 
-    if ($line eq "This game is solveable.")
+    if ($line eq "This game is solveable.\n")
     {
         $self->_reached_end(1);
         $self->_out_line($line);
 
-        while (defined($line = $self->_get_line()))
+        while (defined($line = $self->_l()))
         {
             $self->_out_line($line);
         }
@@ -183,6 +176,8 @@ sub _read_move
         return "END";
     }
 
+    chomp($line);
+
     $self->_move_line($line);
 
     $self->_move(Games::Solitaire::Verify::Move->new(
@@ -285,7 +280,7 @@ sub _apply_move
             $output_state_promise->();
 
 
-            $self->_out_line($move_line);
+            $self->_out_line($move_line."\n");
 
             if (my $verdict = $self->_state()->verify_and_perform_move(
                     Games::Solitaire::Verify::Move->new(
@@ -392,7 +387,7 @@ sub _apply_move
     }
     else
     {
-        $self->_out_line( $self->_move_line );
+        $self->_out_line( $self->_move_line . "\n" );
         if (my $verdict = $self->_state()->verify_and_perform_move($self->_move()))
         {
             Games::Solitaire::Verify::Exception::VerifyMove->throw(
@@ -405,24 +400,6 @@ sub _apply_move
     return;
 }
 
-sub _get_line
-{
-    my $self = shift;
-
-    $self->_line_num($self->_line_num()+1);
-
-    my $ret = readline($self->_input_fh());
-
-    if (!defined($ret))
-    {
-        return;
-    }
-
-    chomp($ret);
-
-    return $ret;
-}
-
 
 sub verify
 {
@@ -430,9 +407,9 @@ sub verify
 
     eval {
 
-        my $line = $self->_get_line();
+        my $line = $self->_l();
 
-        if ($line !~ m{\A(-=)+-\z})
+        if ($line !~ m{\A(-=)+-\n\z})
         {
             die "Incorrect start";
         }
@@ -455,7 +432,7 @@ sub verify
     elsif ($err =
         Exception::Class->caught('Games::Solitaire::Verify::Exception::VerifyMove'))
     {
-        return { error => $err, line_num => $self->_line_num(), };
+        return { error => $err, line_num => $self->_ln(), };
     }
     else
     {
@@ -482,7 +459,7 @@ moves.
 
 =head1 VERSION
 
-version 0.1400
+version 0.1500
 
 =head1 SYNOPSIS
 
@@ -610,7 +587,7 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Games-Solitaire-Verify>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Games-Solitaire-Verify>
 
 =item *
 
@@ -642,7 +619,7 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/Games-Solitaire-Verify>
+L<http://cpants.cpanauthors.org/dist/Games-Solitaire-Verify>
 
 =item *
 
@@ -673,7 +650,7 @@ L<http://deps.cpantesters.org/?module=Games::Solitaire::Verify>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-games-solitaire-verify at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Games-Solitaire-Verify>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Games-Solitaire-Verify>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
