@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 
-our $VERSION = '0.1400';
+our $VERSION = '0.1500';
 
 use parent 'Games::Solitaire::Verify::Base';
 
@@ -777,36 +777,17 @@ sub _verify_and_perform_move_main
     }
 }
 
-sub _stringify_freecells
-{
-    my $self = shift;
-
-    return $self->_freecells()->to_string();
-}
-
-
-sub _stringify_foundations
-{
-    my $self = shift;
-
-    return $self->_foundations()->to_string();
-}
-
 
 sub to_string
 {
     my $self = shift;
 
-    return join("",
-        map { "$_\n" }
+    return join("\n",
         (
-            $self->_stringify_foundations(),
-            $self->_stringify_freecells(),
-            (
-                map { $self->get_column($_)->to_string() }
-                (0 .. ($self->num_columns()-1))
-            )
-        )
+            map { $_->to_string() }
+            $self->_foundations(), $self->_freecells(), @{$self->_columns()}
+        ),
+        ""
     );
 }
 
@@ -825,7 +806,7 @@ states (or positions) of the entire board.
 
 =head1 VERSION
 
-version 0.1400
+version 0.1500
 
 =head1 SYNOPSIS
 
@@ -996,7 +977,7 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Games-Solitaire-Verify>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Games-Solitaire-Verify>
 
 =item *
 
@@ -1028,7 +1009,7 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/Games-Solitaire-Verify>
+L<http://cpants.cpanauthors.org/dist/Games-Solitaire-Verify>
 
 =item *
 
@@ -1059,7 +1040,7 @@ L<http://deps.cpantesters.org/?module=Games::Solitaire::Verify>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-games-solitaire-verify at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Games-Solitaire-Verify>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Games-Solitaire-Verify>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
